@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, Union
 from os import path
 
 from kcu import sh, kpath
@@ -8,7 +8,7 @@ from . import ffprobe
 def reduce_audio_volume(
     path_in: str,
     path_out: str,
-    volume: str = '0.25',
+    volume: Union[int, str] = 0.25,
     debug: bool = False
 ) -> bool:
     sh.sh(
@@ -168,9 +168,13 @@ def add_silence_to_video(
     duration: str = 'shortest',
     debug: bool = False
 ) -> bool:
-    sh.sh(
-        'ffmpeg -f lavfi -y -i anullsrc=channel_layout=stereo:sample_rate={} -i {} -c:v copy -c:a aac -{} {}'.format(str(sample_rate), sh.path(input), duration, sh.path(output)), debug=debug
-    )
+    cmd = 'ffmpeg -f lavfi -y -i anullsrc=channel_layout=stereo:sample_rate={} -i {} -c:v copy -c:a aac '.format(sample_rate, sh.path(input))
+
+    if duration == 'shortest':
+        cmd += '-shortest '
+
+    cmd += sh.path(output)
+    sh.sh(cmd, debug=debug)
 
     return path.exists(output)
 
@@ -186,8 +190,11 @@ def add_audio_to_video(
 
     if not reencode:
         cmd += ' -c:v copy -map 0:v:0 -map 1:a:0'
-    
-    cmd += ' -' + duration + ' ' + sh.path(output)
+
+    if duration == 'shortest':
+        cmd += ' -shortest'
+
+    cmd += ' ' + sh.path(output)
 
     sh.sh(cmd, debug=debug)
 
@@ -216,11 +223,37 @@ def loop(
     out_path: str,
     length_seconds: float,
     debug: bool = False
-):
+) -> bool:
     sh.sh('ffmpeg -y -stream_loop -1 -i ' + sh.path(in_path) + ' -t ' + str(length_seconds) + ' ' + sh.path(out_path), debug=debug)
 
     return path.exists(out_path)
 
+def trim(
+    in_path: str,
+    out_path: str,
+    start_seconds: float = 0,
+    stop_seconds: Optional[float] = None,
+    duration: Optional[float] = None,
+    debug: bool = False
+) -> bool:
+    """PASS EITHER 'stop_seconds' OR 'duration'
+    IF BOTH PASSED, 'duration' will be taken as preference
+    """
+    if stop_seconds is None and duration is None:
+        print('Either, \'stop_seconds\' should e passed or \'duration\'')
+
+        return False
+
+    if duration is None:
+        duration = stop_seconds - start_seconds
+
+    sh.sh(
+        'ffmpeg -y -ss {} -i {} -t {} -c copy {}'.format(__seconds_to_time_str(start_seconds), in_path, __seconds_to_time_str(duration), out_path),
+        debug=debug
+    )
+
+    return path.exists(out_path)
+
 def convert_video_to_16_9(
     in_path: str,
     out_path: str,
@@ -343,4 +376,16 @@ def __loop_together(
         in_video_path = in_audio_path
         in_audio_path = in_reference_path
 
-    return add_audio_to_video(in_audio_path, in_video_path, out, reencode=reencode, debug=debug)
\ No newline at end of file
+    return add_audio_to_video(in_audio_path, in_video_path, out, reencode=reencode, debug=debug)
+
+def __seconds_to_time_str(
+    seconds: float
+) -> str:
+    h = int(seconds/3600)
+    m = int((seconds - h*3600)/60)
+    s = int(seconds - h*3600 - m*60)
+    ms = seconds - int(seconds)
+
+    ms_str = ("%.8f" % (ms)).strip('0') if ms > 0 else ''
+
+    return "%02d:%02d:%02d" % (h, m, s) + ms_str
\ No newline at end of file
